<?php
namespace Teknisa\CTB\Controllers;

use Teknisa\CTB\Services\Ctb10000LancamentosContabeisService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\Row;

class Ctb10000LancamentosContabeisController {

    protected $lancamentosService;

    public function __construct(Ctb10000LancamentosContabeisService $lancamentosService) {
        $this->lancamentosService = $lancamentosService;
    }

    /*
     * Função para buscar as partidas e os rateios de um dado lançamento.
     */
    public function checkValidDataLancamento(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();

            // Chama a função de validação.
            $this->lancamentosService->checkValidDataLancamento($row);
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /*
     * Função para excluir um lançamento.
     */
    public function deleteLanccont(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();

            // Chama a função de validação.
            $this->lancamentosService->deleteLanccont($row);
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /*
     * Função para buscar as partidas e os rateios de um dado lançamento.
     */
    public function getLanccont(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();

            // Busca os arrays de dados.
            $partidas = $this->lancamentosService->getPartidas($row["CDEMPRESA"], $row["NRLANCCONT"]);
            $rateios = $this->lancamentosService->getRateios($row["CDEMPRESA"], $row["NRLANCCONT"]);

            // Cria os respectivos DataSets.
            $partidasDataSet = new DataSet('partidas', $partidas);
            $rateiosDataSet = new DataSet('rateios', $rateios);

            // Adiciona os DataSets no response da requisição.
            $response->addDataSet($partidasDataSet);
            $response->addDataSet($rateiosDataSet);
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /*
     * Função para salvar os dados de um lançamento.
     */
    public function saveLanccont(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();

            // Os dados do lançamento são divididos em cabeçalho, com as
            // informações gerais, e partidas, com cada partida do lançamento.
            $cabecalho = $row["cabecalho"];
            $partidas = $row["partidas"];

            // Salva o lançamento, retornando o seu número identificador.
            $nrlanccont = $this->lancamentosService->saveLanccont($partidas, $cabecalho);

            // Cria o DataSet contendo o número do lançamento.
            $nrlanccontDataSet = new DataSet('columnsToReturn', array("NRLANCCONT" => $nrlanccont));

            // Adiciona o DataSet no response da requisição.
            $response->addDataSet($nrlanccontDataSet);
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function salvardocumento(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();

            $cabecalho = $row["cabecalho"];
            // Chama a função de validação.
            $this->lancamentosService->salvardocumento($cabecalho);

        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    /**
     * Rastreio Contabil
     * @param Row $row
     * @param Response $response
     */
    public function rastreioContabil(Row $row, Response $response)
    {
        try {
            // Dados do Registro
            $rows = $row->getRow();
            
            $rastreioContabil = $this->lancamentosService->rastreioContabil($rows, $response);
            
            $response->addDataSet(new DataSet('rastreioContabil', [$rastreioContabil]));
            
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
}
