<?php
namespace Teknisa\CTB\Controllers;

use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Teknisa\CTB\Services\Ger07700AuditoresIndependentesService;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request\DataSet as RequestDataSet;
use Zeedhi\Framework\DataSource\DataSet;

class Ger07700AuditoresIndependentesController extends \Teknisa\CTB\Controllers\TeknisaCrud {

    protected $dataSourceName;

    protected $newCode;
    protected $environment;
    protected $service;

    public function __construct($crudService, ParameterBag $parameterBag, NewCode $newCode, Environment $environment, Ger07700AuditoresIndependentesService $service) {
        $this->newCode = $newCode;
        $this->environment = $environment;
        $this->service = $service;
        parent::__construct($crudService, $parameterBag);
    }

    public function saveAuditorIndependente(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'auditor_independente';
        $row = $request->getDataSet()->getRows()[0];
        try {
            $this->service->validateAuditor($row);

            //Se for uma nova row, gera código para inserção na tabela
            if ($row['__is_new'] === true) {
                $nrOrg = $this->environment->getNrOrg();
                $tableName = 'AUDINDEPENDENTE';

                $nrSequencial = $this->newCode->getCodeByTableName($tableName, $nrOrg, 1, 0, true);
                $row['NRSEQUENCIAL'] = $nrSequencial;

                $newDataSet = new DataSet($this->dataSourceName, array($row));
                $newRequest = new RequestDataSet($newDataSet, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
                parent::save($newRequest, $response);
            } else {
                parent::save($request, $response);
            }

        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }


    }

    public function findAuditorIndependente(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = 'auditor_independente';
        parent::find($request, $response);
    }

    public function deleteAuditorIndependente(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'auditor_independente';
        parent::delete($request, $response);
    }

    public function findAudIndEmpresa(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = 'auditor_independente_empresa';
        parent::find($request, $response);
    }

    public function saveAudIndEmpresa(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'auditor_independente_empresa';
        $row = $request->getDataSet()->getRows()[0];
        try {
            $this->service->validateRelacao($row);
            //Se for uma nova row, gera código para inserção na tabela
            if ($row['__is_new']) {
                $nrOrg = $this->environment->getNrOrg();
                $tableName = 'AUDINDEMPRESA';

                $nrSequencial = $this->newCode->getCodeByTableName($tableName, $nrOrg, 1, 0, true);
                $row['NRSEQUENCIAL'] = $nrSequencial;

                $newDataSet = new DataSet($this->dataSourceName, array($row));
                $newRequest = new RequestDataSet($newDataSet, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
                parent::save($newRequest, $response);
            } else {
                parent::save($request, $response);
            }

        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }


    }

    public function deleteAudIndEmpresa(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'auditor_independente_empresa';
        parent::delete($request, $response);
    }

    public function findEmpresa(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = 'empresa_auditor';
        parent::find($request, $response);
    }



}
